%include %{_rpmconfigdir}/macros.perl

Name: git
Version: 2.26.2
Release: 2
License: GPL-2.0-only
Summary: Distributed version control system
Url: https://git-scm.com

BuildRequires: libiconv-devel
BuildRequires: curl-devel
BuildRequires: expat-devel
BuildRequires: zlib-devel
BuildRequires: openssl-devel >= 1.1.1
BuildRequires: findutils
BuildRequires: pcre2-devel

Source0: https://www.kernel.org/pub/software/scm/git/git-%{version}.tar.xz

Patch0: config.mak.uname.patch
Patch1: t_t5003-archive-zip.sh.patch
Patch2: git-fileno-macro.patch

%description
Git is a free and open source distributed version control system designed to handle everything from small to very large projects with speed and efficiency.

Git is easy to learn and has a tiny footprint with lightning fast performance. It outclasses SCM tools like Subversion, CVS, Perforce, and ClearCase with features like cheap local branching, convenient staging areas, and multiple workflows. 

%prep
%setup -q

%patch0 -p1
%patch1 -p1
%patch2 -p1

#Fix shebang line
find . -type f -print0 | xargs -0 perl -p -i -e 's|/usr/bin/perl|%{_bindir}/perl|g'

%build

MAKE=`which make`
# generate a script to wrap the make call
# with all the parameters that we need
cat > _make <<EOF
#!/usr/bin/env bash

$MAKE \
  prefix=%{_prefix} \
  sysconfdir=%{_sysconfdir} \
  CC=gcc \
  DESTDIR=%{buildroot} \
  CFLAGS="-maix${OBJECT_MODE} -mminimal-toc -I%{_includedir} -I%{_includedir}/libiconv" \
  LDFLAGS="-maix${OBJECT_MODE} -mminimal-toc -Wl,-brtl -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib -L%{_libdir}" \
  PERL_PATH="%{_bindir}/perl" \
  SHELL_PATH="%{_bindir}/bash" \
  GIT_TEST_CMP='diff -u' \
  NO_TCLTK=YesPlease \
  NO_GETTEXT=YesPlease \
  USE_LIBPCRE2=YesPlease \
  perllibdir=%{perl_sitelib}\
  "\$@"
EOF

chmod +x _make

./_make

%check

# build and run tests
# NOTE: This must be run as a non-*ALLOBJ user or tests will fail
# ./t5570-git-daemon.sh and ./t5811-proto-disable-git.sh require git-daemon, skip
GIT_SKIP_TESTS='t5570 t5811' ./_make test


%install

./_make install

rm %{buildroot}/%{_libexecdir}/git-core/git-daemon
rm %{buildroot}/%{_libexecdir}/git-core/git-p4
rm -r %{buildroot}/%{_datadir}/gitweb

%files
%defattr(-, qsys, *none)

%{_bindir}/*

%{perl_sitelib}/*

%{_libexecdir}/git-core/*

%{_datadir}/git-core/*


%post
# Move gitconfig from old incorrect location /QOpenSys/pkgs/etc/ to new
# correct location /QOpenSys/etc/ if it exists and won't overwrite existing
# gitconfig
if [ -e %{_prefix}/etc/gitconfig -a ! -e %{_sysconfdir}/gitconfig ]
then
  mv %{_prefix}/etc/gitconfig %{_sysconfdir}/gitconfig
fi


%changelog
* Wed Nov 18 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 2.26.2
- Build with PCRE2

* Mon Apr 27 2020 Naveen Ram <naveen.ram@ibm.com> - 2.26.2
- Update git to version 2.26.2
- Fix CVE-2017-14867
- Fix CVE-2020-5260

* Mon Apr 13 2020 Mark Irish <mirish@ibm.com> - 2.10.4
- Pass sysconfdir variable to make to set system config location correctly
- Post install script moves gitconfig to new location if able

* Mon Dec 16 2019 Mark Irish <mirish@ibm.com> - 2.10.4
- Use SPDX license identifier

* Wed Aug 07 2019 Mark Irish <mirish@ibm.com> - 2.10.4
- Update openssl-dev version to >= 1.1.1

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Add build requirements

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Uncomment tests since check sections are disabled by build.py

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove 64-bit GCC script workarounds
- OBJECT_MODE now always set by build and install macros

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Bump to 2.10.4
- Build against expat now that we have it
- Use perl macros
- Remove gitweb and git-p4 along with gitd

* Tue Nov 07 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix license
